# coding: utf-8

"""
    Perigon API

    The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

    The version of the OpenAPI document: 1.0.0
    Contact: data@perigon.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from perigon_sdk.models.category_holder import CategoryHolder
from perigon_sdk.models.company_count import CompanyCount
from perigon_sdk.models.company_holder import CompanyHolder
from perigon_sdk.models.key_point import KeyPoint
from perigon_sdk.models.location_count import LocationCount
from perigon_sdk.models.location_holder import LocationHolder
from perigon_sdk.models.person_count import PersonCount
from perigon_sdk.models.person_holder import PersonHolder
from perigon_sdk.models.question import Question
from perigon_sdk.models.record_stat_holder import RecordStatHolder
from perigon_sdk.models.sentiment_holder import SentimentHolder
from perigon_sdk.models.source_holder import SourceHolder
from perigon_sdk.models.topic_holder import TopicHolder
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing_extensions import Self


class NewsCluster(BaseModel):
    """
    NewsCluster
    """  # noqa: E501

    created_at: Optional[StrictStr] = Field(default=None, alias="createdAt")
    updated_at: Optional[StrictStr] = Field(default=None, alias="updatedAt")
    initialized_at: Optional[StrictStr] = Field(default=None, alias="initializedAt")
    id: Optional[StrictStr] = None
    duplicate_of: Optional[StrictStr] = Field(default=None, alias="duplicateOf")
    slug: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    summary: Optional[StrictStr] = None
    short_summary: Optional[StrictStr] = Field(default=None, alias="shortSummary")
    summary_references: Optional[List[StrictStr]] = Field(
        default=None, alias="summaryReferences"
    )
    image_source: Optional[SourceHolder] = Field(default=None, alias="imageSource")
    image_url: Optional[StrictStr] = Field(default=None, alias="imageUrl")
    key_points: Optional[List[KeyPoint]] = Field(default=None, alias="keyPoints")
    questions: Optional[List[Question]] = None
    unique_sources: Optional[List[StrictStr]] = Field(
        default=None, alias="uniqueSources"
    )
    selected_articles: Optional[List[Article]] = Field(
        default=None, alias="selectedArticles"
    )
    sentiment: Optional[SentimentHolder] = None
    unique_count: Optional[StrictInt] = Field(default=None, alias="uniqueCount")
    reprint_count: Optional[StrictInt] = Field(default=None, alias="reprintCount")
    total_count: Optional[StrictInt] = Field(default=None, alias="totalCount")
    countries: Optional[List[RecordStatHolder]] = None
    top_countries: Optional[List[StrictStr]] = Field(default=None, alias="topCountries")
    topics: Optional[List[RecordStatHolder]] = None
    top_topics: Optional[List[TopicHolder]] = Field(default=None, alias="topTopics")
    categories: Optional[List[RecordStatHolder]] = None
    top_categories: Optional[List[CategoryHolder]] = Field(
        default=None, alias="topCategories"
    )
    taxonomies: Optional[List[RecordStatHolder]] = None
    top_taxonomies: Optional[List[CategoryHolder]] = Field(
        default=None, alias="topTaxonomies"
    )
    people: Optional[List[PersonCount]] = None
    top_people: Optional[List[PersonHolder]] = Field(default=None, alias="topPeople")
    companies: Optional[List[CompanyCount]] = None
    top_companies: Optional[List[CompanyHolder]] = Field(
        default=None, alias="topCompanies"
    )
    locations: Optional[List[LocationCount]] = None
    top_locations: Optional[List[LocationHolder]] = Field(
        default=None, alias="topLocations"
    )
    __properties: ClassVar[List[str]] = [
        "createdAt",
        "updatedAt",
        "initializedAt",
        "id",
        "duplicateOf",
        "slug",
        "name",
        "summary",
        "shortSummary",
        "summaryReferences",
        "imageSource",
        "imageUrl",
        "keyPoints",
        "questions",
        "uniqueSources",
        "selectedArticles",
        "sentiment",
        "uniqueCount",
        "reprintCount",
        "totalCount",
        "countries",
        "topCountries",
        "topics",
        "topTopics",
        "categories",
        "topCategories",
        "taxonomies",
        "topTaxonomies",
        "people",
        "topPeople",
        "companies",
        "topCompanies",
        "locations",
        "topLocations",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NewsCluster from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of image_source
        if self.image_source:
            _dict["imageSource"] = self.image_source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in key_points (list)
        _items = []
        if self.key_points:
            for _item_key_points in self.key_points:
                if _item_key_points:
                    _items.append(_item_key_points.to_dict())
            _dict["keyPoints"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in questions (list)
        _items = []
        if self.questions:
            for _item_questions in self.questions:
                if _item_questions:
                    _items.append(_item_questions.to_dict())
            _dict["questions"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in selected_articles (list)
        _items = []
        if self.selected_articles:
            for _item_selected_articles in self.selected_articles:
                if _item_selected_articles:
                    _items.append(_item_selected_articles.to_dict())
            _dict["selectedArticles"] = _items
        # override the default output from pydantic by calling `to_dict()` of sentiment
        if self.sentiment:
            _dict["sentiment"] = self.sentiment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in countries (list)
        _items = []
        if self.countries:
            for _item_countries in self.countries:
                if _item_countries:
                    _items.append(_item_countries.to_dict())
            _dict["countries"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in topics (list)
        _items = []
        if self.topics:
            for _item_topics in self.topics:
                if _item_topics:
                    _items.append(_item_topics.to_dict())
            _dict["topics"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_topics (list)
        _items = []
        if self.top_topics:
            for _item_top_topics in self.top_topics:
                if _item_top_topics:
                    _items.append(_item_top_topics.to_dict())
            _dict["topTopics"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in categories (list)
        _items = []
        if self.categories:
            for _item_categories in self.categories:
                if _item_categories:
                    _items.append(_item_categories.to_dict())
            _dict["categories"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_categories (list)
        _items = []
        if self.top_categories:
            for _item_top_categories in self.top_categories:
                if _item_top_categories:
                    _items.append(_item_top_categories.to_dict())
            _dict["topCategories"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in taxonomies (list)
        _items = []
        if self.taxonomies:
            for _item_taxonomies in self.taxonomies:
                if _item_taxonomies:
                    _items.append(_item_taxonomies.to_dict())
            _dict["taxonomies"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_taxonomies (list)
        _items = []
        if self.top_taxonomies:
            for _item_top_taxonomies in self.top_taxonomies:
                if _item_top_taxonomies:
                    _items.append(_item_top_taxonomies.to_dict())
            _dict["topTaxonomies"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in people (list)
        _items = []
        if self.people:
            for _item_people in self.people:
                if _item_people:
                    _items.append(_item_people.to_dict())
            _dict["people"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_people (list)
        _items = []
        if self.top_people:
            for _item_top_people in self.top_people:
                if _item_top_people:
                    _items.append(_item_top_people.to_dict())
            _dict["topPeople"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in companies (list)
        _items = []
        if self.companies:
            for _item_companies in self.companies:
                if _item_companies:
                    _items.append(_item_companies.to_dict())
            _dict["companies"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_companies (list)
        _items = []
        if self.top_companies:
            for _item_top_companies in self.top_companies:
                if _item_top_companies:
                    _items.append(_item_top_companies.to_dict())
            _dict["topCompanies"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in locations (list)
        _items = []
        if self.locations:
            for _item_locations in self.locations:
                if _item_locations:
                    _items.append(_item_locations.to_dict())
            _dict["locations"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_locations (list)
        _items = []
        if self.top_locations:
            for _item_top_locations in self.top_locations:
                if _item_top_locations:
                    _items.append(_item_top_locations.to_dict())
            _dict["topLocations"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NewsCluster from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "createdAt": obj.get("createdAt"),
                "updatedAt": obj.get("updatedAt"),
                "initializedAt": obj.get("initializedAt"),
                "id": obj.get("id"),
                "duplicateOf": obj.get("duplicateOf"),
                "slug": obj.get("slug"),
                "name": obj.get("name"),
                "summary": obj.get("summary"),
                "shortSummary": obj.get("shortSummary"),
                "summaryReferences": obj.get("summaryReferences"),
                "imageSource": SourceHolder.from_dict(obj["imageSource"])
                if obj.get("imageSource") is not None
                else None,
                "imageUrl": obj.get("imageUrl"),
                "keyPoints": [KeyPoint.from_dict(_item) for _item in obj["keyPoints"]]
                if obj.get("keyPoints") is not None
                else None,
                "questions": [Question.from_dict(_item) for _item in obj["questions"]]
                if obj.get("questions") is not None
                else None,
                "uniqueSources": obj.get("uniqueSources"),
                "selectedArticles": [
                    Article.from_dict(_item) for _item in obj["selectedArticles"]
                ]
                if obj.get("selectedArticles") is not None
                else None,
                "sentiment": SentimentHolder.from_dict(obj["sentiment"])
                if obj.get("sentiment") is not None
                else None,
                "uniqueCount": obj.get("uniqueCount"),
                "reprintCount": obj.get("reprintCount"),
                "totalCount": obj.get("totalCount"),
                "countries": [
                    RecordStatHolder.from_dict(_item) for _item in obj["countries"]
                ]
                if obj.get("countries") is not None
                else None,
                "topCountries": obj.get("topCountries"),
                "topics": [RecordStatHolder.from_dict(_item) for _item in obj["topics"]]
                if obj.get("topics") is not None
                else None,
                "topTopics": [
                    TopicHolder.from_dict(_item) for _item in obj["topTopics"]
                ]
                if obj.get("topTopics") is not None
                else None,
                "categories": [
                    RecordStatHolder.from_dict(_item) for _item in obj["categories"]
                ]
                if obj.get("categories") is not None
                else None,
                "topCategories": [
                    CategoryHolder.from_dict(_item) for _item in obj["topCategories"]
                ]
                if obj.get("topCategories") is not None
                else None,
                "taxonomies": [
                    RecordStatHolder.from_dict(_item) for _item in obj["taxonomies"]
                ]
                if obj.get("taxonomies") is not None
                else None,
                "topTaxonomies": [
                    CategoryHolder.from_dict(_item) for _item in obj["topTaxonomies"]
                ]
                if obj.get("topTaxonomies") is not None
                else None,
                "people": [PersonCount.from_dict(_item) for _item in obj["people"]]
                if obj.get("people") is not None
                else None,
                "topPeople": [
                    PersonHolder.from_dict(_item) for _item in obj["topPeople"]
                ]
                if obj.get("topPeople") is not None
                else None,
                "companies": [
                    CompanyCount.from_dict(_item) for _item in obj["companies"]
                ]
                if obj.get("companies") is not None
                else None,
                "topCompanies": [
                    CompanyHolder.from_dict(_item) for _item in obj["topCompanies"]
                ]
                if obj.get("topCompanies") is not None
                else None,
                "locations": [
                    LocationCount.from_dict(_item) for _item in obj["locations"]
                ]
                if obj.get("locations") is not None
                else None,
                "topLocations": [
                    LocationHolder.from_dict(_item) for _item in obj["topLocations"]
                ]
                if obj.get("topLocations") is not None
                else None,
            }
        )
        return _obj


from perigon_sdk.models.article import Article

# TODO: Rewrite to not use raise_errors
NewsCluster.model_rebuild(raise_errors=False)



# coding: utf-8

"""
    Perigon API

    The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

    The version of the OpenAPI document: 1.0.0
    Contact: data@perigon.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from perigon_sdk.models.coordinate_filter import CoordinateFilter
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing_extensions import Self


class ArticleSearchFilter(BaseModel):
    """
    A versatile filter object to refine search results based on articles, clusters, sources, languages, categories, locations, companies, and people. Supports logical operators (AND, OR, NOT) for complex queries. Accepts single values or arrays, with arrays applied as OR operations.
    """  # noqa: E501

    article_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific article(s). Array of article IDs. For convenience, a single string ID is also accepted.",
        alias="articleId",
    )
    cluster_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific cluster(s). Accepts either a single string or an array of strings.",
        alias="clusterId",
    )
    source: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific source(s). Accepts either a single string or an array of strings.",
    )
    exclude_source: Optional[List[StrictStr]] = Field(
        default=None,
        description="The domain of the website, which should be excluded from the search. Multiple parameters could be provided. Wildcards (* and ?) are suported (e.g. *.cnn.com).",
        alias="excludeSource",
    )
    source_group: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific source group, for example: 'top100'. Accepts either a single string or an array of strings.",
        alias="sourceGroup",
    )
    language: Optional[List[StrictStr]] = Field(
        default=None,
        description="Language code to filter by language. If an array parameters are passed, they will be applied as OR operations. For example: ['en', 'es']. Language ISO codes must be provided.",
    )
    exclude_language: Optional[List[StrictStr]] = Field(
        default=None,
        description=" A list of languages to be excluded. Any article published in one of the languages provided in this filter will not be returned. This is useful when you are interested only in news published in specific languages.",
        alias="excludeLanguage",
    )
    label: Optional[List[StrictStr]] = Field(
        default=None,
        description="Labels to filter by, could be 'Opinion', 'Paid-news', 'Non-news', etc. If multiple parameters are passed, they will be applied as OR operations. ",
    )
    exclude_label: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude results that include specific labels (Opinion, Non-news, Paid News, etc.). You can filter multiple by repeating the parameter.",
        alias="excludeLabel",
    )
    taxonomy: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filters by Google Content Categories. This field will accept 1 or more categories, must pass the full name of the category. Example: taxonomy=/Finance/Banking/Other, /Finance/Investing/Funds",
    )
    category: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by categories. Categories are general themes that the article is about. Examples of categories: Tech, Politics, etc. If multiple parameters are passed, they will be applied as OR operations. Use 'none' to search uncategorized articles.",
    )
    topic: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by topics. Each topic is some kind of entity that the article is about. Examples of topics: Markets, Joe Biden, Green Energy, Climate Change, Cryptocurrency, etc. If multiple parameters are passed, they will be applied as OR operations.",
    )
    exclude_topic: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by excluding topics. Each topic is some kind of entity that the article is about. Examples of topics: Markets, Joe Biden, Green Energy, Climate Change, Cryptocurrency, etc. If multiple parameters are passed, they will be applied as OR operations.",
        alias="excludeTopic",
    )
    country: Optional[List[StrictStr]] = Field(
        default=None,
        description="Country code to filter by country. If multiple parameters are passed, they will be applied as OR operations. Only accepts country ISO codes.",
    )
    exclude_country: Optional[List[StrictStr]] = Field(
        default=None,
        description="Excludes articles from specific countries in the vector search results. Accepts a list of country codes (e.g., 'US', 'UK', 'CA'). Use this parameter to filter out articles published in countries you don't want to include in your search results. See the Country and Language Support section in the documentation for a full list of supported country codes.",
        alias="excludeCountry",
    )
    locations_country: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filters articles where a specified country plays a central role in the content, beyond mere mentions, to ensure the results are deeply relevant to the country in question. If multiple parameters are passed, they will be applied as OR operations. Only accepts country ISO codes.",
        alias="locationsCountry",
    )
    exclude_locations_country: Optional[List[StrictStr]] = Field(
        default=None,
        description="Excludes articles where a specified country plays a central role in the content, ensuring results are not deeply relevant to the country in question. If multiple parameters are passed, they will be applied as AND operations, excluding articles relevant to any of the specified countries.",
        alias="excludeLocationsCountry",
    )
    state: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filters articles where a specified state plays a central role in the content, beyond mere mentions, to ensure the results are deeply relevant to the state in question. If multiple parameters are passed, they will be applied as OR operations. Only accepts state ISO codes.",
    )
    exclude_state: Optional[List[StrictStr]] = Field(
        default=None,
        description="A list of states to exclude. Articles that include, or are associated with, any of the states provided here will be filtered out. This is especially useful if you want to ignore news tied to certain geographical areas (e.g., US states).",
        alias="excludeState",
    )
    county: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filters articles where a specified state plays a central role in the content, beyond mere mentions, to ensure the results are deeply relevant to the state in question. If multiple parameters are passed, they will be applied as OR operations.",
    )
    exclude_county: Optional[List[StrictStr]] = Field(
        default=None,
        description="Excludes articles from specific counties or administrative divisions in the vector search results. Accepts either a single county name or a list of county names. County names should match the format used in article metadata (e.g., 'Los Angeles County', 'Cook County'). This parameter allows for more granular geographic filter",
        alias="excludeCounty",
    )
    city: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filters articles where a specified city plays a central role in the content, beyond mere mentions, to ensure the results are deeply relevant to the urban area in question. If multiple parameters are passed, they will be applied as OR operations.",
    )
    exclude_city: Optional[List[StrictStr]] = Field(
        default=None,
        description="A list of cities to exclude from the results. Articles that are associated with any of the specified cities will be filtered out.",
        alias="excludeCity",
    )
    source_country: Optional[List[StrictStr]] = Field(
        default=None,
        description="Find articles published by sources that are located within a given country. Must be 2 character country code (i.e. us, gb, etc).",
        alias="sourceCountry",
    )
    source_state: Optional[List[StrictStr]] = Field(
        default=None,
        description="Find articles published by sources that are located within a given state.",
        alias="sourceState",
    )
    source_county: Optional[List[StrictStr]] = Field(
        default=None,
        description="Find articles published by sources that are located within a given county.",
        alias="sourceCounty",
    )
    source_city: Optional[List[StrictStr]] = Field(
        default=None,
        description="Find articles published by sources that are located within a given city.",
        alias="sourceCity",
    )
    coordinates: Optional[CoordinateFilter] = None
    source_coordinates: Optional[CoordinateFilter] = Field(
        default=None, alias="sourceCoordinates"
    )
    company_id: Optional[List[StrictStr]] = Field(
        default=None, description="List of company IDs to filter by.", alias="companyId"
    )
    exclude_company_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="A list of company identifiers. Articles associated with companies that have any of these unique IDs will be filtered out from the returned results, ensuring that certain companies or corporate entities are not included.",
        alias="excludeCompanyId",
    )
    company_domain: Optional[List[StrictStr]] = Field(
        default=None,
        description="Search by company domains for filtering. E.g. companyDomain=apple.com.",
        alias="companyDomain",
    )
    exclude_company_domain: Optional[List[StrictStr]] = Field(
        default=None,
        description='A list of company domains to exclude. If an article is related to a company that uses one of the specified domains (for instance, "example.com"), it will not be returned in the results.',
        alias="excludeCompanyDomain",
    )
    company_symbol: Optional[List[StrictStr]] = Field(
        default=None, description="Search by company symbols.", alias="companySymbol"
    )
    exclude_company_symbol: Optional[List[StrictStr]] = Field(
        default=None,
        description="A list of stock symbols (ticker symbols) that identify companies to be excluded. Articles related to companies using any of these symbols will be omitted, which is useful for targeting or avoiding specific public companies.",
        alias="excludeCompanySymbol",
    )
    company_name: Optional[List[StrictStr]] = Field(
        default=None, description="Search by company name.", alias="companyName"
    )
    person_wikidata_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="List of person Wikidata IDs for filtering.",
        alias="personWikidataId",
    )
    exclude_person_wikidata_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="A list of Wikidata identifiers for individuals. Articles mentioning persons with any of these Wikidata IDs will be filtered out. This is particularly helpful when using a unique identifier to prevent ambiguity in names.",
        alias="excludePersonWikidataId",
    )
    person_name: Optional[List[StrictStr]] = Field(
        default=None,
        description="List of person names for exact matches. Boolean and complex logic is not supported on this filter.",
        alias="personName",
    )
    exclude_person_name: Optional[List[StrictStr]] = Field(
        default=None,
        description="A list of person names that, when associated with the content, cause the article to be excluded. This filter removes articles related to any individuals whose names match those on the list.",
        alias="excludePersonName",
    )
    var_and: Optional[List[ArticleSearchFilter]] = Field(
        default=None,
        description="Adds additional AND filter objects. These objects must be of the same type as the original filter object and will be combined with the existing filter using the AND logical operator.",
        alias="AND",
    )
    var_or: Optional[List[ArticleSearchFilter]] = Field(
        default=None,
        description="Adds additional OR filter objects. These objects must be of the same type as the original filter object and will be combined with the existing filter using the OR logical operator.",
        alias="OR",
    )
    var_not: Optional[List[ArticleSearchFilter]] = Field(
        default=None,
        description="A filter object for logical NOT operations",
        alias="NOT",
    )
    __properties: ClassVar[List[str]] = [
        "articleId",
        "clusterId",
        "source",
        "excludeSource",
        "sourceGroup",
        "language",
        "excludeLanguage",
        "label",
        "excludeLabel",
        "taxonomy",
        "category",
        "topic",
        "excludeTopic",
        "country",
        "excludeCountry",
        "locationsCountry",
        "excludeLocationsCountry",
        "state",
        "excludeState",
        "county",
        "excludeCounty",
        "city",
        "excludeCity",
        "sourceCountry",
        "sourceState",
        "sourceCounty",
        "sourceCity",
        "coordinates",
        "sourceCoordinates",
        "companyId",
        "excludeCompanyId",
        "companyDomain",
        "excludeCompanyDomain",
        "companySymbol",
        "excludeCompanySymbol",
        "companyName",
        "personWikidataId",
        "excludePersonWikidataId",
        "personName",
        "excludePersonName",
        "AND",
        "OR",
        "NOT",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ArticleSearchFilter from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of coordinates
        if self.coordinates:
            _dict["coordinates"] = self.coordinates.to_dict()
        # override the default output from pydantic by calling `to_dict()` of source_coordinates
        if self.source_coordinates:
            _dict["sourceCoordinates"] = self.source_coordinates.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in var_and (list)
        _items = []
        if self.var_and:
            for _item_var_and in self.var_and:
                if _item_var_and:
                    _items.append(_item_var_and.to_dict())
            _dict["AND"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in var_or (list)
        _items = []
        if self.var_or:
            for _item_var_or in self.var_or:
                if _item_var_or:
                    _items.append(_item_var_or.to_dict())
            _dict["OR"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in var_not (list)
        _items = []
        if self.var_not:
            for _item_var_not in self.var_not:
                if _item_var_not:
                    _items.append(_item_var_not.to_dict())
            _dict["NOT"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ArticleSearchFilter from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "articleId": obj.get("articleId"),
                "clusterId": obj.get("clusterId"),
                "source": obj.get("source"),
                "excludeSource": obj.get("excludeSource"),
                "sourceGroup": obj.get("sourceGroup"),
                "language": obj.get("language"),
                "excludeLanguage": obj.get("excludeLanguage"),
                "label": obj.get("label"),
                "excludeLabel": obj.get("excludeLabel"),
                "taxonomy": obj.get("taxonomy"),
                "category": obj.get("category"),
                "topic": obj.get("topic"),
                "excludeTopic": obj.get("excludeTopic"),
                "country": obj.get("country"),
                "excludeCountry": obj.get("excludeCountry"),
                "locationsCountry": obj.get("locationsCountry"),
                "excludeLocationsCountry": obj.get("excludeLocationsCountry"),
                "state": obj.get("state"),
                "excludeState": obj.get("excludeState"),
                "county": obj.get("county"),
                "excludeCounty": obj.get("excludeCounty"),
                "city": obj.get("city"),
                "excludeCity": obj.get("excludeCity"),
                "sourceCountry": obj.get("sourceCountry"),
                "sourceState": obj.get("sourceState"),
                "sourceCounty": obj.get("sourceCounty"),
                "sourceCity": obj.get("sourceCity"),
                "coordinates": CoordinateFilter.from_dict(obj["coordinates"])
                if obj.get("coordinates") is not None
                else None,
                "sourceCoordinates": CoordinateFilter.from_dict(
                    obj["sourceCoordinates"]
                )
                if obj.get("sourceCoordinates") is not None
                else None,
                "companyId": obj.get("companyId"),
                "excludeCompanyId": obj.get("excludeCompanyId"),
                "companyDomain": obj.get("companyDomain"),
                "excludeCompanyDomain": obj.get("excludeCompanyDomain"),
                "companySymbol": obj.get("companySymbol"),
                "excludeCompanySymbol": obj.get("excludeCompanySymbol"),
                "companyName": obj.get("companyName"),
                "personWikidataId": obj.get("personWikidataId"),
                "excludePersonWikidataId": obj.get("excludePersonWikidataId"),
                "personName": obj.get("personName"),
                "excludePersonName": obj.get("excludePersonName"),
                "AND": [ArticleSearchFilter.from_dict(_item) for _item in obj["AND"]]
                if obj.get("AND") is not None
                else None,
                "OR": [ArticleSearchFilter.from_dict(_item) for _item in obj["OR"]]
                if obj.get("OR") is not None
                else None,
                "NOT": [ArticleSearchFilter.from_dict(_item) for _item in obj["NOT"]]
                if obj.get("NOT") is not None
                else None,
            }
        )
        return _obj


# TODO: Rewrite to not use raise_errors
ArticleSearchFilter.model_rebuild(raise_errors=False)



# coding: utf-8

"""
    Perigon API

    The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

    The version of the OpenAPI document: 1.0.0
    Contact: data@perigon.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set, Union

from perigon_sdk.models.category_holder import CategoryHolder
from perigon_sdk.models.category_with_score_holder import CategoryWithScoreHolder
from perigon_sdk.models.company_holder import CompanyHolder
from perigon_sdk.models.entity_holder import EntityHolder
from perigon_sdk.models.event_type_holder import EventTypeHolder
from perigon_sdk.models.id_name_holder import IdNameHolder
from perigon_sdk.models.journalist import Journalist
from perigon_sdk.models.keyword_holder import KeywordHolder
from perigon_sdk.models.label_holder import LabelHolder
from perigon_sdk.models.location_holder import LocationHolder
from perigon_sdk.models.person_holder import PersonHolder
from perigon_sdk.models.place import Place
from perigon_sdk.models.sentiment_holder import SentimentHolder
from perigon_sdk.models.source_holder import SourceHolder
from perigon_sdk.models.topic_holder import TopicHolder
from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictBool,
    StrictFloat,
    StrictInt,
    StrictStr,
)
from typing_extensions import Self


class Article(BaseModel):
    """
    Article
    """  # noqa: E501

    url: Optional[StrictStr] = None
    authors_byline: Optional[StrictStr] = Field(default=None, alias="authorsByline")
    article_id: Optional[StrictStr] = Field(default=None, alias="articleId")
    cluster_id: Optional[StrictStr] = Field(default=None, alias="clusterId")
    source: Optional[SourceHolder] = None
    image_url: Optional[StrictStr] = Field(default=None, alias="imageUrl")
    country: Optional[StrictStr] = None
    language: Optional[StrictStr] = None
    pub_date: Optional[StrictStr] = Field(default=None, alias="pubDate")
    add_date: Optional[StrictStr] = Field(default=None, alias="addDate")
    refresh_date: Optional[StrictStr] = Field(default=None, alias="refreshDate")
    score: Optional[Union[StrictFloat, StrictInt]] = None
    title: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    content: Optional[StrictStr] = None
    medium: Optional[StrictStr] = None
    links: Optional[List[StrictStr]] = None
    labels: Optional[List[LabelHolder]] = None
    event_types: Optional[List[EventTypeHolder]] = Field(
        default=None, alias="eventTypes"
    )
    matched_authors: Optional[List[IdNameHolder]] = Field(
        default=None, alias="matchedAuthors"
    )
    claim: Optional[StrictStr] = None
    verdict: Optional[StrictStr] = None
    keywords: Optional[List[KeywordHolder]] = None
    topics: Optional[List[TopicHolder]] = None
    categories: Optional[List[CategoryHolder]] = None
    taxonomies: Optional[List[CategoryWithScoreHolder]] = None
    entities: Optional[List[EntityHolder]] = None
    companies: Optional[List[CompanyHolder]] = None
    sentiment: Optional[SentimentHolder] = None
    summary: Optional[StrictStr] = None
    short_summary: Optional[StrictStr] = Field(default=None, alias="shortSummary")
    translation: Optional[StrictStr] = None
    translated_title: Optional[StrictStr] = Field(default=None, alias="translatedTitle")
    translated_description: Optional[StrictStr] = Field(
        default=None, alias="translatedDescription"
    )
    translated_summary: Optional[StrictStr] = Field(
        default=None, alias="translatedSummary"
    )
    locations: Optional[List[LocationHolder]] = None
    reprint: Optional[StrictBool] = None
    reprint_group_id: Optional[StrictStr] = Field(default=None, alias="reprintGroupId")
    places: Optional[List[Place]] = None
    people: Optional[List[PersonHolder]] = None
    cluster: Optional[NewsCluster] = None
    journalists: Optional[List[Journalist]] = None
    highlights: Optional[Dict[str, List[StrictStr]]] = None
    __properties: ClassVar[List[str]] = [
        "url",
        "authorsByline",
        "articleId",
        "clusterId",
        "source",
        "imageUrl",
        "country",
        "language",
        "pubDate",
        "addDate",
        "refreshDate",
        "score",
        "title",
        "description",
        "content",
        "medium",
        "links",
        "labels",
        "eventTypes",
        "matchedAuthors",
        "claim",
        "verdict",
        "keywords",
        "topics",
        "categories",
        "taxonomies",
        "entities",
        "companies",
        "sentiment",
        "summary",
        "shortSummary",
        "translation",
        "translatedTitle",
        "translatedDescription",
        "translatedSummary",
        "locations",
        "reprint",
        "reprintGroupId",
        "places",
        "people",
        "cluster",
        "journalists",
        "highlights",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Article from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict["source"] = self.source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in labels (list)
        _items = []
        if self.labels:
            for _item_labels in self.labels:
                if _item_labels:
                    _items.append(_item_labels.to_dict())
            _dict["labels"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in event_types (list)
        _items = []
        if self.event_types:
            for _item_event_types in self.event_types:
                if _item_event_types:
                    _items.append(_item_event_types.to_dict())
            _dict["eventTypes"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in matched_authors (list)
        _items = []
        if self.matched_authors:
            for _item_matched_authors in self.matched_authors:
                if _item_matched_authors:
                    _items.append(_item_matched_authors.to_dict())
            _dict["matchedAuthors"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in keywords (list)
        _items = []
        if self.keywords:
            for _item_keywords in self.keywords:
                if _item_keywords:
                    _items.append(_item_keywords.to_dict())
            _dict["keywords"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in topics (list)
        _items = []
        if self.topics:
            for _item_topics in self.topics:
                if _item_topics:
                    _items.append(_item_topics.to_dict())
            _dict["topics"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in categories (list)
        _items = []
        if self.categories:
            for _item_categories in self.categories:
                if _item_categories:
                    _items.append(_item_categories.to_dict())
            _dict["categories"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in taxonomies (list)
        _items = []
        if self.taxonomies:
            for _item_taxonomies in self.taxonomies:
                if _item_taxonomies:
                    _items.append(_item_taxonomies.to_dict())
            _dict["taxonomies"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in entities (list)
        _items = []
        if self.entities:
            for _item_entities in self.entities:
                if _item_entities:
                    _items.append(_item_entities.to_dict())
            _dict["entities"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in companies (list)
        _items = []
        if self.companies:
            for _item_companies in self.companies:
                if _item_companies:
                    _items.append(_item_companies.to_dict())
            _dict["companies"] = _items
        # override the default output from pydantic by calling `to_dict()` of sentiment
        if self.sentiment:
            _dict["sentiment"] = self.sentiment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in locations (list)
        _items = []
        if self.locations:
            for _item_locations in self.locations:
                if _item_locations:
                    _items.append(_item_locations.to_dict())
            _dict["locations"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in places (list)
        _items = []
        if self.places:
            for _item_places in self.places:
                if _item_places:
                    _items.append(_item_places.to_dict())
            _dict["places"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in people (list)
        _items = []
        if self.people:
            for _item_people in self.people:
                if _item_people:
                    _items.append(_item_people.to_dict())
            _dict["people"] = _items
        # override the default output from pydantic by calling `to_dict()` of cluster
        if self.cluster:
            _dict["cluster"] = self.cluster.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in journalists (list)
        _items = []
        if self.journalists:
            for _item_journalists in self.journalists:
                if _item_journalists:
                    _items.append(_item_journalists.to_dict())
            _dict["journalists"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Article from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "url": obj.get("url"),
                "authorsByline": obj.get("authorsByline"),
                "articleId": obj.get("articleId"),
                "clusterId": obj.get("clusterId"),
                "source": SourceHolder.from_dict(obj["source"])
                if obj.get("source") is not None
                else None,
                "imageUrl": obj.get("imageUrl"),
                "country": obj.get("country"),
                "language": obj.get("language"),
                "pubDate": obj.get("pubDate"),
                "addDate": obj.get("addDate"),
                "refreshDate": obj.get("refreshDate"),
                "score": obj.get("score"),
                "title": obj.get("title"),
                "description": obj.get("description"),
                "content": obj.get("content"),
                "medium": obj.get("medium"),
                "links": obj.get("links"),
                "labels": [LabelHolder.from_dict(_item) for _item in obj["labels"]]
                if obj.get("labels") is not None
                else None,
                "eventTypes": [
                    EventTypeHolder.from_dict(_item) for _item in obj["eventTypes"]
                ]
                if obj.get("eventTypes") is not None
                else None,
                "matchedAuthors": [
                    IdNameHolder.from_dict(_item) for _item in obj["matchedAuthors"]
                ]
                if obj.get("matchedAuthors") is not None
                else None,
                "claim": obj.get("claim"),
                "verdict": obj.get("verdict"),
                "keywords": [
                    KeywordHolder.from_dict(_item) for _item in obj["keywords"]
                ]
                if obj.get("keywords") is not None
                else None,
                "topics": [TopicHolder.from_dict(_item) for _item in obj["topics"]]
                if obj.get("topics") is not None
                else None,
                "categories": [
                    CategoryHolder.from_dict(_item) for _item in obj["categories"]
                ]
                if obj.get("categories") is not None
                else None,
                "taxonomies": [
                    CategoryWithScoreHolder.from_dict(_item)
                    for _item in obj["taxonomies"]
                ]
                if obj.get("taxonomies") is not None
                else None,
                "entities": [EntityHolder.from_dict(_item) for _item in obj["entities"]]
                if obj.get("entities") is not None
                else None,
                "companies": [
                    CompanyHolder.from_dict(_item) for _item in obj["companies"]
                ]
                if obj.get("companies") is not None
                else None,
                "sentiment": SentimentHolder.from_dict(obj["sentiment"])
                if obj.get("sentiment") is not None
                else None,
                "summary": obj.get("summary"),
                "shortSummary": obj.get("shortSummary"),
                "translation": obj.get("translation"),
                "translatedTitle": obj.get("translatedTitle"),
                "translatedDescription": obj.get("translatedDescription"),
                "translatedSummary": obj.get("translatedSummary"),
                "locations": [
                    LocationHolder.from_dict(_item) for _item in obj["locations"]
                ]
                if obj.get("locations") is not None
                else None,
                "reprint": obj.get("reprint"),
                "reprintGroupId": obj.get("reprintGroupId"),
                "places": [Place.from_dict(_item) for _item in obj["places"]]
                if obj.get("places") is not None
                else None,
                "people": [PersonHolder.from_dict(_item) for _item in obj["people"]]
                if obj.get("people") is not None
                else None,
                "cluster": NewsCluster.from_dict(obj["cluster"])
                if obj.get("cluster") is not None
                else None,
                "journalists": [
                    Journalist.from_dict(_item) for _item in obj["journalists"]
                ]
                if obj.get("journalists") is not None
                else None,
                "highlights": obj.get("highlights"),
            }
        )
        return _obj


from perigon_sdk.models.news_cluster import NewsCluster

# TODO: Rewrite to not use raise_errors
Article.model_rebuild(raise_errors=False)



# coding: utf-8

# flake8: noqa
"""
    Perigon API

    The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

    The version of the OpenAPI document: 1.0.0
    Contact: data@perigon.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from perigon_sdk.models.article import Article
from perigon_sdk.models.article_search_filter import ArticleSearchFilter
from perigon_sdk.models.article_search_params import ArticleSearchParams
from perigon_sdk.models.auth_exception import AuthException
from perigon_sdk.models.auth_exception_cause import AuthExceptionCause
from perigon_sdk.models.auth_exception_cause_stack_trace_inner import (
    AuthExceptionCauseStackTraceInner,
)
from perigon_sdk.models.category_holder import CategoryHolder
from perigon_sdk.models.category_with_score_holder import CategoryWithScoreHolder
from perigon_sdk.models.company_count import CompanyCount
from perigon_sdk.models.company_holder import CompanyHolder
from perigon_sdk.models.coordinate import Coordinate
from perigon_sdk.models.coordinate_filter import CoordinateFilter
from perigon_sdk.models.entity_holder import EntityHolder
from perigon_sdk.models.event_type_holder import EventTypeHolder
from perigon_sdk.models.id_name_holder import IdNameHolder
from perigon_sdk.models.illegal_parameter_exception import IllegalParameterException
from perigon_sdk.models.internal_error_exception import InternalErrorException
from perigon_sdk.models.journalist import Journalist
from perigon_sdk.models.key_point import KeyPoint
from perigon_sdk.models.keyword_holder import KeywordHolder
from perigon_sdk.models.label_holder import LabelHolder
from perigon_sdk.models.location_count import LocationCount
from perigon_sdk.models.location_holder import LocationHolder
from perigon_sdk.models.name_count import NameCount
from perigon_sdk.models.news_cluster import NewsCluster
from perigon_sdk.models.not_found_exception import NotFoundException
from perigon_sdk.models.person_count import PersonCount
from perigon_sdk.models.person_holder import PersonHolder
from perigon_sdk.models.place import Place
from perigon_sdk.models.query_search_result import QuerySearchResult
from perigon_sdk.models.question import Question
from perigon_sdk.models.record_stat_holder import RecordStatHolder
from perigon_sdk.models.search_result import SearchResult
from perigon_sdk.models.sentiment_holder import SentimentHolder
from perigon_sdk.models.source_holder import SourceHolder
from perigon_sdk.models.source_location import SourceLocation
from perigon_sdk.models.standard_search_result import StandardSearchResult
from perigon_sdk.models.table_search_result import TableSearchResult
from perigon_sdk.models.too_many_requests_exception import TooManyRequestsException
from perigon_sdk.models.topic_holder import TopicHolder



from typing import Any, Dict, Optional

from perigon_sdk.api_client import ApiClient
from perigon_sdk.models.article_search_params import ArticleSearchParams
from perigon_sdk.models.search_result import SearchResult


class NaturalLanguageApi:
    """"""

    def __init__(self, api_client: Optional[ApiClient] = None):
        self.api_client = api_client or ApiClient()

    # ----------------- vector_search_articles (sync) ----------------- #
    def vector_search_articles(
        self, article_search_params: ArticleSearchParams
    ) -> SearchResult:
        """Vector"""
        path = "/v1/vector/news/all"

        # --- build query dict on the fly ---
        params: Dict[str, Any] = {}

        resp = self.api_client.request(
            "POST", path, params=params, json=article_search_params
        )
        resp.raise_for_status()

        return SearchResult.model_validate(resp.text)

    # ---------------- vector_search_articles_async ------------------- #
    async def vector_search_articles_async(
        self, article_search_params: ArticleSearchParams
    ) -> SearchResult:
        """Vector (async)"""
        path = "/v1/vector/news/all"

        params: Dict[str, Any] = {}

        resp = await self.api_client.request_async(
            "POST", path, params=params, json=article_search_params
        )
        resp.raise_for_status()

        return SearchResult.model_validate(resp.text)



from typing import Any, Dict, Optional, Union

from perigon_sdk.api_client import ApiClient
from perigon_sdk.models.query_search_result import QuerySearchResult
from perigon_sdk.models.standard_search_result import StandardSearchResult
from pydantic import Field, StrictBool, StrictStr
from typing_extensions import Annotated


class NewsStoriesApi:
    """"""

    def __init__(self, api_client: Optional[ApiClient] = None):
        self.api_client = api_client or ApiClient()

    # ----------------- search_articles (sync) ----------------- #
    def search_articles(
        self,
        q: Optional[str] = None,
        title: Optional[str] = None,
        desc: Optional[str] = None,
        content: Optional[str] = None,
        url: Optional[str] = None,
        article_id: Optional[str] = None,
        cluster_id: Optional[str] = None,
        sort_by: Optional[str] = None,
        page: Optional[int] = None,
        size: Optional[int] = None,
        var_from: Optional[str] = None,
        to: Optional[str] = None,
        add_date_from: Optional[str] = None,
        add_date_to: Optional[str] = None,
        refresh_date_from: Optional[str] = None,
        refresh_date_to: Optional[str] = None,
        medium: Optional[str] = None,
        source: Optional[str] = None,
        source_group: Optional[str] = None,
        exclude_source_group: Optional[str] = None,
        exclude_source: Optional[str] = None,
        paywall: Optional[str] = None,
        byline: Optional[str] = None,
        author: Optional[str] = None,
        exclude_author: Optional[str] = None,
        journalist_id: Optional[str] = None,
        exclude_journalist_id: Optional[str] = None,
        language: Optional[str] = None,
        exclude_language: Optional[str] = None,
        search_translation: Optional[str] = None,
        label: Optional[str] = None,
        exclude_label: Optional[str] = None,
        category: Optional[str] = None,
        exclude_category: Optional[str] = None,
        topic: Optional[str] = None,
        exclude_topic: Optional[str] = None,
        link_to: Optional[str] = None,
        show_reprints: Optional[str] = None,
        reprint_group_id: Optional[str] = None,
        city: Optional[str] = None,
        exclude_city: Optional[str] = None,
        area: Optional[str] = None,
        state: Optional[str] = None,
        exclude_state: Optional[str] = None,
        county: Optional[str] = None,
        exclude_county: Optional[str] = None,
        locations_country: Optional[str] = None,
        country: Optional[str] = None,
        exclude_locations_country: Optional[str] = None,
        location: Optional[str] = None,
        lat: Optional[float] = None,
        lon: Optional[float] = None,
        max_distance: Optional[float] = None,
        source_city: Optional[str] = None,
        source_county: Optional[str] = None,
        source_country: Optional[str] = None,
        source_state: Optional[str] = None,
        source_lat: Optional[float] = None,
        source_lon: Optional[float] = None,
        source_max_distance: Optional[float] = None,
        person_wikidata_id: Optional[str] = None,
        exclude_person_wikidata_id: Optional[str] = None,
        person_name: Optional[str] = None,
        exclude_person_name: Optional[str] = None,
        company_id: Optional[str] = None,
        exclude_company_id: Optional[str] = None,
        company_name: Optional[str] = None,
        company_domain: Optional[str] = None,
        exclude_company_domain: Optional[str] = None,
        company_symbol: Optional[str] = None,
        exclude_company_symbol: Optional[str] = None,
        show_num_results: Optional[str] = None,
        positive_sentiment_from: Optional[str] = None,
        positive_sentiment_to: Optional[str] = None,
        neutral_sentiment_from: Optional[str] = None,
        neutral_sentiment_to: Optional[str] = None,
        negative_sentiment_from: Optional[str] = None,
        negative_sentiment_to: Optional[str] = None,
        taxonomy: Optional[str] = None,
        prefix_taxonomy: Optional[str] = None,
    ) -> QuerySearchResult:
        """Articles"""
        path = "/v1/all"

        # --- build query dict on the fly ---
        params: Dict[str, Any] = {}
        if q is not None:
            params["q"] = q
        if title is not None:
            params["title"] = title
        if desc is not None:
            params["desc"] = desc
        if content is not None:
            params["content"] = content
        if url is not None:
            params["url"] = url
        if article_id is not None:
            params["articleId"] = article_id
        if cluster_id is not None:
            params["clusterId"] = cluster_id
        if sort_by is not None:
            params["sortBy"] = sort_by
        if page is not None:
            params["page"] = page
        if size is not None:
            params["size"] = size
        if var_from is not None:
            params["from"] = var_from
        if to is not None:
            params["to"] = to
        if add_date_from is not None:
            params["addDateFrom"] = add_date_from
        if add_date_to is not None:
            params["addDateTo"] = add_date_to
        if refresh_date_from is not None:
            params["refreshDateFrom"] = refresh_date_from
        if refresh_date_to is not None:
            params["refreshDateTo"] = refresh_date_to
        if medium is not None:
            params["medium"] = medium
        if source is not None:
            params["source"] = source
        if source_group is not None:
            params["sourceGroup"] = source_group
        if exclude_source_group is not None:
            params["excludeSourceGroup"] = exclude_source_group
        if exclude_source is not None:
            params["excludeSource"] = exclude_source
        if paywall is not None:
            params["paywall"] = paywall
        if byline is not None:
            params["byline"] = byline
        if author is not None:
            params["author"] = author
        if exclude_author is not None:
            params["excludeAuthor"] = exclude_author
        if journalist_id is not None:
            params["journalistId"] = journalist_id
        if exclude_journalist_id is not None:
            params["excludeJournalistId"] = exclude_journalist_id
        if language is not None:
            params["language"] = language
        if exclude_language is not None:
            params["excludeLanguage"] = exclude_language
        if search_translation is not None:
            params["searchTranslation"] = search_translation
        if label is not None:
            params["label"] = label
        if exclude_label is not None:
            params["excludeLabel"] = exclude_label
        if category is not None:
            params["category"] = category
        if exclude_category is not None:
            params["excludeCategory"] = exclude_category
        if topic is not None:
            params["topic"] = topic
        if exclude_topic is not None:
            params["excludeTopic"] = exclude_topic
        if link_to is not None:
            params["linkTo"] = link_to
        if show_reprints is not None:
            params["showReprints"] = show_reprints
        if reprint_group_id is not None:
            params["reprintGroupId"] = reprint_group_id
        if city is not None:
            params["city"] = city
        if exclude_city is not None:
            params["excludeCity"] = exclude_city
        if area is not None:
            params["area"] = area
        if state is not None:
            params["state"] = state
        if exclude_state is not None:
            params["excludeState"] = exclude_state
        if county is not None:
            params["county"] = county
        if exclude_county is not None:
            params["excludeCounty"] = exclude_county
        if locations_country is not None:
            params["locationsCountry"] = locations_country
        if country is not None:
            params["country"] = country
        if exclude_locations_country is not None:
            params["excludeLocationsCountry"] = exclude_locations_country
        if location is not None:
            params["location"] = location
        if lat is not None:
            params["lat"] = lat
        if lon is not None:
            params["lon"] = lon
        if max_distance is not None:
            params["maxDistance"] = max_distance
        if source_city is not None:
            params["sourceCity"] = source_city
        if source_county is not None:
            params["sourceCounty"] = source_county
        if source_country is not None:
            params["sourceCountry"] = source_country
        if source_state is not None:
            params["sourceState"] = source_state
        if source_lat is not None:
            params["sourceLat"] = source_lat
        if source_lon is not None:
            params["sourceLon"] = source_lon
        if source_max_distance is not None:
            params["sourceMaxDistance"] = source_max_distance
        if person_wikidata_id is not None:
            params["personWikidataId"] = person_wikidata_id
        if exclude_person_wikidata_id is not None:
            params["excludePersonWikidataId"] = exclude_person_wikidata_id
        if person_name is not None:
            params["personName"] = person_name
        if exclude_person_name is not None:
            params["excludePersonName"] = exclude_person_name
        if company_id is not None:
            params["companyId"] = company_id
        if exclude_company_id is not None:
            params["excludeCompanyId"] = exclude_company_id
        if company_name is not None:
            params["companyName"] = company_name
        if company_domain is not None:
            params["companyDomain"] = company_domain
        if exclude_company_domain is not None:
            params["excludeCompanyDomain"] = exclude_company_domain
        if company_symbol is not None:
            params["companySymbol"] = company_symbol
        if exclude_company_symbol is not None:
            params["excludeCompanySymbol"] = exclude_company_symbol
        if show_num_results is not None:
            params["showNumResults"] = show_num_results
        if positive_sentiment_from is not None:
            params["positiveSentimentFrom"] = positive_sentiment_from
        if positive_sentiment_to is not None:
            params["positiveSentimentTo"] = positive_sentiment_to
        if neutral_sentiment_from is not None:
            params["neutralSentimentFrom"] = neutral_sentiment_from
        if neutral_sentiment_to is not None:
            params["neutralSentimentTo"] = neutral_sentiment_to
        if negative_sentiment_from is not None:
            params["negativeSentimentFrom"] = negative_sentiment_from
        if negative_sentiment_to is not None:
            params["negativeSentimentTo"] = negative_sentiment_to
        if taxonomy is not None:
            params["taxonomy"] = taxonomy
        if prefix_taxonomy is not None:
            params["prefixTaxonomy"] = prefix_taxonomy

        resp = self.api_client.request("GET", path, params=params)
        resp.raise_for_status()

        return QuerySearchResult.model_validate(resp.text)

    # ---------------- search_articles_async ------------------- #
    async def search_articles_async(
        self,
        q: Optional[str] = None,
        title: Optional[str] = None,
        desc: Optional[str] = None,
        content: Optional[str] = None,
        url: Optional[str] = None,
        article_id: Optional[str] = None,
        cluster_id: Optional[str] = None,
        sort_by: Optional[str] = None,
        page: Optional[int] = None,
        size: Optional[int] = None,
        var_from: Optional[str] = None,
        to: Optional[str] = None,
        add_date_from: Optional[str] = None,
        add_date_to: Optional[str] = None,
        refresh_date_from: Optional[str] = None,
        refresh_date_to: Optional[str] = None,
        medium: Optional[str] = None,
        source: Optional[str] = None,
        source_group: Optional[str] = None,
        exclude_source_group: Optional[str] = None,
        exclude_source: Optional[str] = None,
        paywall: Optional[str] = None,
        byline: Optional[str] = None,
        author: Optional[str] = None,
        exclude_author: Optional[str] = None,
        journalist_id: Optional[str] = None,
        exclude_journalist_id: Optional[str] = None,
        language: Optional[str] = None,
        exclude_language: Optional[str] = None,
        search_translation: Optional[str] = None,
        label: Optional[str] = None,
        exclude_label: Optional[str] = None,
        category: Optional[str] = None,
        exclude_category: Optional[str] = None,
        topic: Optional[str] = None,
        exclude_topic: Optional[str] = None,
        link_to: Optional[str] = None,
        show_reprints: Optional[str] = None,
        reprint_group_id: Optional[str] = None,
        city: Optional[str] = None,
        exclude_city: Optional[str] = None,
        area: Optional[str] = None,
        state: Optional[str] = None,
        exclude_state: Optional[str] = None,
        county: Optional[str] = None,
        exclude_county: Optional[str] = None,
        locations_country: Optional[str] = None,
        country: Optional[str] = None,
        exclude_locations_country: Optional[str] = None,
        location: Optional[str] = None,
        lat: Optional[float] = None,
        lon: Optional[float] = None,
        max_distance: Optional[float] = None,
        source_city: Optional[str] = None,
        source_county: Optional[str] = None,
        source_country: Optional[str] = None,
        source_state: Optional[str] = None,
        source_lat: Optional[float] = None,
        source_lon: Optional[float] = None,
        source_max_distance: Optional[float] = None,
        person_wikidata_id: Optional[str] = None,
        exclude_person_wikidata_id: Optional[str] = None,
        person_name: Optional[str] = None,
        exclude_person_name: Optional[str] = None,
        company_id: Optional[str] = None,
        exclude_company_id: Optional[str] = None,
        company_name: Optional[str] = None,
        company_domain: Optional[str] = None,
        exclude_company_domain: Optional[str] = None,
        company_symbol: Optional[str] = None,
        exclude_company_symbol: Optional[str] = None,
        show_num_results: Optional[str] = None,
        positive_sentiment_from: Optional[str] = None,
        positive_sentiment_to: Optional[str] = None,
        neutral_sentiment_from: Optional[str] = None,
        neutral_sentiment_to: Optional[str] = None,
        negative_sentiment_from: Optional[str] = None,
        negative_sentiment_to: Optional[str] = None,
        taxonomy: Optional[str] = None,
        prefix_taxonomy: Optional[str] = None,
    ) -> QuerySearchResult:
        """Articles (async)"""
        path = "/v1/all"

        params: Dict[str, Any] = {}
        if q is not None:
            params["q"] = q
        if title is not None:
            params["title"] = title
        if desc is not None:
            params["desc"] = desc
        if content is not None:
            params["content"] = content
        if url is not None:
            params["url"] = url
        if article_id is not None:
            params["articleId"] = article_id
        if cluster_id is not None:
            params["clusterId"] = cluster_id
        if sort_by is not None:
            params["sortBy"] = sort_by
        if page is not None:
            params["page"] = page
        if size is not None:
            params["size"] = size
        if var_from is not None:
            params["from"] = var_from
        if to is not None:
            params["to"] = to
        if add_date_from is not None:
            params["addDateFrom"] = add_date_from
        if add_date_to is not None:
            params["addDateTo"] = add_date_to
        if refresh_date_from is not None:
            params["refreshDateFrom"] = refresh_date_from
        if refresh_date_to is not None:
            params["refreshDateTo"] = refresh_date_to
        if medium is not None:
            params["medium"] = medium
        if source is not None:
            params["source"] = source
        if source_group is not None:
            params["sourceGroup"] = source_group
        if exclude_source_group is not None:
            params["excludeSourceGroup"] = exclude_source_group
        if exclude_source is not None:
            params["excludeSource"] = exclude_source
        if paywall is not None:
            params["paywall"] = paywall
        if byline is not None:
            params["byline"] = byline
        if author is not None:
            params["author"] = author
        if exclude_author is not None:
            params["excludeAuthor"] = exclude_author
        if journalist_id is not None:
            params["journalistId"] = journalist_id
        if exclude_journalist_id is not None:
            params["excludeJournalistId"] = exclude_journalist_id
        if language is not None:
            params["language"] = language
        if exclude_language is not None:
            params["excludeLanguage"] = exclude_language
        if search_translation is not None:
            params["searchTranslation"] = search_translation
        if label is not None:
            params["label"] = label
        if exclude_label is not None:
            params["excludeLabel"] = exclude_label
        if category is not None:
            params["category"] = category
        if exclude_category is not None:
            params["excludeCategory"] = exclude_category
        if topic is not None:
            params["topic"] = topic
        if exclude_topic is not None:
            params["excludeTopic"] = exclude_topic
        if link_to is not None:
            params["linkTo"] = link_to
        if show_reprints is not None:
            params["showReprints"] = show_reprints
        if reprint_group_id is not None:
            params["reprintGroupId"] = reprint_group_id
        if city is not None:
            params["city"] = city
        if exclude_city is not None:
            params["excludeCity"] = exclude_city
        if area is not None:
            params["area"] = area
        if state is not None:
            params["state"] = state
        if exclude_state is not None:
            params["excludeState"] = exclude_state
        if county is not None:
            params["county"] = county
        if exclude_county is not None:
            params["excludeCounty"] = exclude_county
        if locations_country is not None:
            params["locationsCountry"] = locations_country
        if country is not None:
            params["country"] = country
        if exclude_locations_country is not None:
            params["excludeLocationsCountry"] = exclude_locations_country
        if location is not None:
            params["location"] = location
        if lat is not None:
            params["lat"] = lat
        if lon is not None:
            params["lon"] = lon
        if max_distance is not None:
            params["maxDistance"] = max_distance
        if source_city is not None:
            params["sourceCity"] = source_city
        if source_county is not None:
            params["sourceCounty"] = source_county
        if source_country is not None:
            params["sourceCountry"] = source_country
        if source_state is not None:
            params["sourceState"] = source_state
        if source_lat is not None:
            params["sourceLat"] = source_lat
        if source_lon is not None:
            params["sourceLon"] = source_lon
        if source_max_distance is not None:
            params["sourceMaxDistance"] = source_max_distance
        if person_wikidata_id is not None:
            params["personWikidataId"] = person_wikidata_id
        if exclude_person_wikidata_id is not None:
            params["excludePersonWikidataId"] = exclude_person_wikidata_id
        if person_name is not None:
            params["personName"] = person_name
        if exclude_person_name is not None:
            params["excludePersonName"] = exclude_person_name
        if company_id is not None:
            params["companyId"] = company_id
        if exclude_company_id is not None:
            params["excludeCompanyId"] = exclude_company_id
        if company_name is not None:
            params["companyName"] = company_name
        if company_domain is not None:
            params["companyDomain"] = company_domain
        if exclude_company_domain is not None:
            params["excludeCompanyDomain"] = exclude_company_domain
        if company_symbol is not None:
            params["companySymbol"] = company_symbol
        if exclude_company_symbol is not None:
            params["excludeCompanySymbol"] = exclude_company_symbol
        if show_num_results is not None:
            params["showNumResults"] = show_num_results
        if positive_sentiment_from is not None:
            params["positiveSentimentFrom"] = positive_sentiment_from
        if positive_sentiment_to is not None:
            params["positiveSentimentTo"] = positive_sentiment_to
        if neutral_sentiment_from is not None:
            params["neutralSentimentFrom"] = neutral_sentiment_from
        if neutral_sentiment_to is not None:
            params["neutralSentimentTo"] = neutral_sentiment_to
        if negative_sentiment_from is not None:
            params["negativeSentimentFrom"] = negative_sentiment_from
        if negative_sentiment_to is not None:
            params["negativeSentimentTo"] = negative_sentiment_to
        if taxonomy is not None:
            params["taxonomy"] = taxonomy
        if prefix_taxonomy is not None:
            params["prefixTaxonomy"] = prefix_taxonomy

        resp = await self.api_client.request_async("GET", path, params=params)
        resp.raise_for_status()

        return QuerySearchResult.model_validate(resp.text)

    # ----------------- search_stories (sync) ----------------- #
    def search_stories(
        self,
        q: Optional[str] = None,
        name: Optional[str] = None,
        cluster_id: Optional[str] = None,
        sort_by: Optional[str] = None,
        page: Optional[int] = None,
        size: Optional[int] = None,
        var_from: Optional[str] = None,
        to: Optional[str] = None,
        topic: Optional[str] = None,
        category: Optional[str] = None,
        taxonomy: Optional[str] = None,
        source: Optional[str] = None,
        source_group: Optional[str] = None,
        min_unique_sources: Optional[int] = None,
        person_wikidata_id: Optional[str] = None,
        person_name: Optional[str] = None,
        company_id: Optional[str] = None,
        company_name: Optional[str] = None,
        company_domain: Optional[str] = None,
        company_symbol: Optional[str] = None,
        country: Optional[str] = None,
        state: Optional[str] = None,
        city: Optional[str] = None,
        area: Optional[str] = None,
        min_cluster_size: Optional[int] = None,
        max_cluster_size: Optional[str] = None,
        name_exists: Optional[str] = None,
        positive_sentiment_from: Optional[str] = None,
        positive_sentiment_to: Optional[str] = None,
        neutral_sentiment_from: Optional[str] = None,
        neutral_sentiment_to: Optional[str] = None,
        negative_sentiment_from: Optional[str] = None,
        negative_sentiment_to: Optional[str] = None,
        initialized_from: Optional[str] = None,
        initialized_to: Optional[str] = None,
        updated_from: Optional[str] = None,
        updated_to: Optional[str] = None,
        show_story_page_info: Optional[bool] = None,
        show_num_results: Optional[str] = None,
        show_duplicates: Optional[str] = None,
        exclude_cluster_id: Optional[str] = None,
    ) -> StandardSearchResult:
        """Stories"""
        path = "/v1/stories/all"

        # --- build query dict on the fly ---
        params: Dict[str, Any] = {}
        if q is not None:
            params["q"] = q
        if name is not None:
            params["name"] = name
        if cluster_id is not None:
            params["clusterId"] = cluster_id
        if sort_by is not None:
            params["sortBy"] = sort_by
        if page is not None:
            params["page"] = page
        if size is not None:
            params["size"] = size
        if var_from is not None:
            params["from"] = var_from
        if to is not None:
            params["to"] = to
        if topic is not None:
            params["topic"] = topic
        if category is not None:
            params["category"] = category
        if taxonomy is not None:
            params["taxonomy"] = taxonomy
        if source is not None:
            params["source"] = source
        if source_group is not None:
            params["sourceGroup"] = source_group
        if min_unique_sources is not None:
            params["minUniqueSources"] = min_unique_sources
        if person_wikidata_id is not None:
            params["personWikidataId"] = person_wikidata_id
        if person_name is not None:
            params["personName"] = person_name
        if company_id is not None:
            params["companyId"] = company_id
        if company_name is not None:
            params["companyName"] = company_name
        if company_domain is not None:
            params["companyDomain"] = company_domain
        if company_symbol is not None:
            params["companySymbol"] = company_symbol
        if country is not None:
            params["country"] = country
        if state is not None:
            params["state"] = state
        if city is not None:
            params["city"] = city
        if area is not None:
            params["area"] = area
        if min_cluster_size is not None:
            params["minClusterSize"] = min_cluster_size
        if max_cluster_size is not None:
            params["maxClusterSize"] = max_cluster_size
        if name_exists is not None:
            params["nameExists"] = name_exists
        if positive_sentiment_from is not None:
            params["positiveSentimentFrom"] = positive_sentiment_from
        if positive_sentiment_to is not None:
            params["positiveSentimentTo"] = positive_sentiment_to
        if neutral_sentiment_from is not None:
            params["neutralSentimentFrom"] = neutral_sentiment_from
        if neutral_sentiment_to is not None:
            params["neutralSentimentTo"] = neutral_sentiment_to
        if negative_sentiment_from is not None:
            params["negativeSentimentFrom"] = negative_sentiment_from
        if negative_sentiment_to is not None:
            params["negativeSentimentTo"] = negative_sentiment_to
        if initialized_from is not None:
            params["initializedFrom"] = initialized_from
        if initialized_to is not None:
            params["initializedTo"] = initialized_to
        if updated_from is not None:
            params["updatedFrom"] = updated_from
        if updated_to is not None:
            params["updatedTo"] = updated_to
        if show_story_page_info is not None:
            params["showStoryPageInfo"] = show_story_page_info
        if show_num_results is not None:
            params["showNumResults"] = show_num_results
        if show_duplicates is not None:
            params["showDuplicates"] = show_duplicates
        if exclude_cluster_id is not None:
            params["excludeClusterId"] = exclude_cluster_id

        resp = self.api_client.request("GET", path, params=params)
        resp.raise_for_status()

        return StandardSearchResult.model_validate(resp.text)

    # ---------------- search_stories_async ------------------- #
    async def search_stories_async(
        self,
        q: Optional[str] = None,
        name: Optional[str] = None,
        cluster_id: Optional[str] = None,
        sort_by: Optional[str] = None,
        page: Optional[int] = None,
        size: Optional[int] = None,
        var_from: Optional[str] = None,
        to: Optional[str] = None,
        topic: Optional[str] = None,
        category: Optional[str] = None,
        taxonomy: Optional[str] = None,
        source: Optional[str] = None,
        source_group: Optional[str] = None,
        min_unique_sources: Optional[int] = None,
        person_wikidata_id: Optional[str] = None,
        person_name: Optional[str] = None,
        company_id: Optional[str] = None,
        company_name: Optional[str] = None,
        company_domain: Optional[str] = None,
        company_symbol: Optional[str] = None,
        country: Optional[str] = None,
        state: Optional[str] = None,
        city: Optional[str] = None,
        area: Optional[str] = None,
        min_cluster_size: Optional[int] = None,
        max_cluster_size: Optional[str] = None,
        name_exists: Optional[str] = None,
        positive_sentiment_from: Optional[str] = None,
        positive_sentiment_to: Optional[str] = None,
        neutral_sentiment_from: Optional[str] = None,
        neutral_sentiment_to: Optional[str] = None,
        negative_sentiment_from: Optional[str] = None,
        negative_sentiment_to: Optional[str] = None,
        initialized_from: Optional[str] = None,
        initialized_to: Optional[str] = None,
        updated_from: Optional[str] = None,
        updated_to: Optional[str] = None,
        show_story_page_info: Optional[bool] = None,
        show_num_results: Optional[str] = None,
        show_duplicates: Optional[str] = None,
        exclude_cluster_id: Optional[str] = None,
    ) -> StandardSearchResult:
        """Stories (async)"""
        path = "/v1/stories/all"

        params: Dict[str, Any] = {}
        if q is not None:
            params["q"] = q
        if name is not None:
            params["name"] = name
        if cluster_id is not None:
            params["clusterId"] = cluster_id
        if sort_by is not None:
            params["sortBy"] = sort_by
        if page is not None:
            params["page"] = page
        if size is not None:
            params["size"] = size
        if var_from is not None:
            params["from"] = var_from
        if to is not None:
            params["to"] = to
        if topic is not None:
            params["topic"] = topic
        if category is not None:
            params["category"] = category
        if taxonomy is not None:
            params["taxonomy"] = taxonomy
        if source is not None:
            params["source"] = source
        if source_group is not None:
            params["sourceGroup"] = source_group
        if min_unique_sources is not None:
            params["minUniqueSources"] = min_unique_sources
        if person_wikidata_id is not None:
            params["personWikidataId"] = person_wikidata_id
        if person_name is not None:
            params["personName"] = person_name
        if company_id is not None:
            params["companyId"] = company_id
        if company_name is not None:
            params["companyName"] = company_name
        if company_domain is not None:
            params["companyDomain"] = company_domain
        if company_symbol is not None:
            params["companySymbol"] = company_symbol
        if country is not None:
            params["country"] = country
        if state is not None:
            params["state"] = state
        if city is not None:
            params["city"] = city
        if area is not None:
            params["area"] = area
        if min_cluster_size is not None:
            params["minClusterSize"] = min_cluster_size
        if max_cluster_size is not None:
            params["maxClusterSize"] = max_cluster_size
        if name_exists is not None:
            params["nameExists"] = name_exists
        if positive_sentiment_from is not None:
            params["positiveSentimentFrom"] = positive_sentiment_from
        if positive_sentiment_to is not None:
            params["positiveSentimentTo"] = positive_sentiment_to
        if neutral_sentiment_from is not None:
            params["neutralSentimentFrom"] = neutral_sentiment_from
        if neutral_sentiment_to is not None:
            params["neutralSentimentTo"] = neutral_sentiment_to
        if negative_sentiment_from is not None:
            params["negativeSentimentFrom"] = negative_sentiment_from
        if negative_sentiment_to is not None:
            params["negativeSentimentTo"] = negative_sentiment_to
        if initialized_from is not None:
            params["initializedFrom"] = initialized_from
        if initialized_to is not None:
            params["initializedTo"] = initialized_to
        if updated_from is not None:
            params["updatedFrom"] = updated_from
        if updated_to is not None:
            params["updatedTo"] = updated_to
        if show_story_page_info is not None:
            params["showStoryPageInfo"] = show_story_page_info
        if show_num_results is not None:
            params["showNumResults"] = show_num_results
        if show_duplicates is not None:
            params["showDuplicates"] = show_duplicates
        if exclude_cluster_id is not None:
            params["excludeClusterId"] = exclude_cluster_id

        resp = await self.api_client.request_async("GET", path, params=params)
        resp.raise_for_status()

        return StandardSearchResult.model_validate(resp.text)



from typing import Any, Dict, Optional, Union

from perigon_sdk.api_client import ApiClient
from perigon_sdk.models.journalist import Journalist
from perigon_sdk.models.standard_search_result import StandardSearchResult
from perigon_sdk.models.table_search_result import TableSearchResult
from pydantic import Field, StrictStr
from typing_extensions import Annotated


class SupplementalEndpointsApi:
    """"""

    def __init__(self, api_client: Optional[ApiClient] = None):
        self.api_client = api_client or ApiClient()

    # ----------------- get_journalist_by_id (sync) ----------------- #
    def get_journalist_by_id(self, id: str) -> Journalist:
        """Journalists ID"""
        path = "/v1/journalists/{id}"
        path = path.replace("{$id}", str(id))

        # --- build query dict on the fly ---
        params: Dict[str, Any] = {}

        resp = self.api_client.request("GET", path, params=params)
        resp.raise_for_status()

        return Journalist.model_validate(resp.text)

    # ---------------- get_journalist_by_id_async ------------------- #
    async def get_journalist_by_id_async(self, id: str) -> Journalist:
        """Journalists ID (async)"""
        path = "/v1/journalists/{id}"
        path = path.replace("{$id}", str(id))

        params: Dict[str, Any] = {}

        resp = await self.api_client.request_async("GET", path, params=params)
        resp.raise_for_status()

        return Journalist.model_validate(resp.text)

    # ----------------- search_companies (sync) ----------------- #
    def search_companies(
        self,
        id: Optional[str] = None,
        symbol: Optional[str] = None,
        domain: Optional[str] = None,
        country: Optional[str] = None,
        exchange: Optional[str] = None,
        num_employees_from: Optional[str] = None,
        num_employees_to: Optional[str] = None,
        ipo_from: Optional[str] = None,
        ipo_to: Optional[str] = None,
        q: Optional[str] = None,
        name: Optional[str] = None,
        industry: Optional[str] = None,
        sector: Optional[str] = None,
        size: Optional[int] = None,
        page: Optional[int] = None,
    ) -> StandardSearchResult:
        """Companies"""
        path = "/v1/companies/all"

        # --- build query dict on the fly ---
        params: Dict[str, Any] = {}
        if id is not None:
            params["id"] = id
        if symbol is not None:
            params["symbol"] = symbol
        if domain is not None:
            params["domain"] = domain
        if country is not None:
            params["country"] = country
        if exchange is not None:
            params["exchange"] = exchange
        if num_employees_from is not None:
            params["numEmployeesFrom"] = num_employees_from
        if num_employees_to is not None:
            params["numEmployeesTo"] = num_employees_to
        if ipo_from is not None:
            params["ipoFrom"] = ipo_from
        if ipo_to is not None:
            params["ipoTo"] = ipo_to
        if q is not None:
            params["q"] = q
        if name is not None:
            params["name"] = name
        if industry is not None:
            params["industry"] = industry
        if sector is not None:
            params["sector"] = sector
        if size is not None:
            params["size"] = size
        if page is not None:
            params["page"] = page

        resp = self.api_client.request("GET", path, params=params)
        resp.raise_for_status()

        return StandardSearchResult.model_validate(resp.text)

    # ---------------- search_companies_async ------------------- #
    async def search_companies_async(
        self,
        id: Optional[str] = None,
        symbol: Optional[str] = None,
        domain: Optional[str] = None,
        country: Optional[str] = None,
        exchange: Optional[str] = None,
        num_employees_from: Optional[str] = None,
        num_employees_to: Optional[str] = None,
        ipo_from: Optional[str] = None,
        ipo_to: Optional[str] = None,
        q: Optional[str] = None,
        name: Optional[str] = None,
        industry: Optional[str] = None,
        sector: Optional[str] = None,
        size: Optional[int] = None,
        page: Optional[int] = None,
    ) -> StandardSearchResult:
        """Companies (async)"""
        path = "/v1/companies/all"

        params: Dict[str, Any] = {}
        if id is not None:
            params["id"] = id
        if symbol is not None:
            params["symbol"] = symbol
        if domain is not None:
            params["domain"] = domain
        if country is not None:
            params["country"] = country
        if exchange is not None:
            params["exchange"] = exchange
        if num_employees_from is not None:
            params["numEmployeesFrom"] = num_employees_from
        if num_employees_to is not None:
            params["numEmployeesTo"] = num_employees_to
        if ipo_from is not None:
            params["ipoFrom"] = ipo_from
        if ipo_to is not None:
            params["ipoTo"] = ipo_to
        if q is not None:
            params["q"] = q
        if name is not None:
            params["name"] = name
        if industry is not None:
            params["industry"] = industry
        if sector is not None:
            params["sector"] = sector
        if size is not None:
            params["size"] = size
        if page is not None:
            params["page"] = page

        resp = await self.api_client.request_async("GET", path, params=params)
        resp.raise_for_status()

        return StandardSearchResult.model_validate(resp.text)

    # ----------------- search_journalists1 (sync) ----------------- #
    def search_journalists1(
        self,
        id: Optional[str] = None,
        q: Optional[str] = None,
        name: Optional[str] = None,
        twitter: Optional[str] = None,
        size: Optional[int] = None,
        page: Optional[int] = None,
        source: Optional[str] = None,
        topic: Optional[str] = None,
        category: Optional[str] = None,
        label: Optional[str] = None,
        min_monthly_posts: Optional[str] = None,
        max_monthly_posts: Optional[str] = None,
        country: Optional[str] = None,
        updated_at_from: Optional[str] = None,
        updated_at_to: Optional[str] = None,
        show_num_results: Optional[str] = None,
    ) -> StandardSearchResult:
        """Journalists"""
        path = "/v1/journalists/all"

        # --- build query dict on the fly ---
        params: Dict[str, Any] = {}
        if id is not None:
            params["id"] = id
        if q is not None:
            params["q"] = q
        if name is not None:
            params["name"] = name
        if twitter is not None:
            params["twitter"] = twitter
        if size is not None:
            params["size"] = size
        if page is not None:
            params["page"] = page
        if source is not None:
            params["source"] = source
        if topic is not None:
            params["topic"] = topic
        if category is not None:
            params["category"] = category
        if label is not None:
            params["label"] = label
        if min_monthly_posts is not None:
            params["minMonthlyPosts"] = min_monthly_posts
        if max_monthly_posts is not None:
            params["maxMonthlyPosts"] = max_monthly_posts
        if country is not None:
            params["country"] = country
        if updated_at_from is not None:
            params["updatedAtFrom"] = updated_at_from
        if updated_at_to is not None:
            params["updatedAtTo"] = updated_at_to
        if show_num_results is not None:
            params["showNumResults"] = show_num_results

        resp = self.api_client.request("GET", path, params=params)
        resp.raise_for_status()

        return StandardSearchResult.model_validate(resp.text)

    # ---------------- search_journalists1_async ------------------- #
    async def search_journalists1_async(
        self,
        id: Optional[str] = None,
        q: Optional[str] = None,
        name: Optional[str] = None,
        twitter: Optional[str] = None,
        size: Optional[int] = None,
        page: Optional[int] = None,
        source: Optional[str] = None,
        topic: Optional[str] = None,
        category: Optional[str] = None,
        label: Optional[str] = None,
        min_monthly_posts: Optional[str] = None,
        max_monthly_posts: Optional[str] = None,
        country: Optional[str] = None,
        updated_at_from: Optional[str] = None,
        updated_at_to: Optional[str] = None,
        show_num_results: Optional[str] = None,
    ) -> StandardSearchResult:
        """Journalists (async)"""
        path = "/v1/journalists/all"

        params: Dict[str, Any] = {}
        if id is not None:
            params["id"] = id
        if q is not None:
            params["q"] = q
        if name is not None:
            params["name"] = name
        if twitter is not None:
            params["twitter"] = twitter
        if size is not None:
            params["size"] = size
        if page is not None:
            params["page"] = page
        if source is not None:
            params["source"] = source
        if topic is not None:
            params["topic"] = topic
        if category is not None:
            params["category"] = category
        if label is not None:
            params["label"] = label
        if min_monthly_posts is not None:
            params["minMonthlyPosts"] = min_monthly_posts
        if max_monthly_posts is not None:
            params["maxMonthlyPosts"] = max_monthly_posts
        if country is not None:
            params["country"] = country
        if updated_at_from is not None:
            params["updatedAtFrom"] = updated_at_from
        if updated_at_to is not None:
            params["updatedAtTo"] = updated_at_to
        if show_num_results is not None:
            params["showNumResults"] = show_num_results

        resp = await self.api_client.request_async("GET", path, params=params)
        resp.raise_for_status()

        return StandardSearchResult.model_validate(resp.text)

    # ----------------- search_people (sync) ----------------- #
    def search_people(
        self,
        name: Optional[str] = None,
        wikidata_id: Optional[str] = None,
        occupation_id: Optional[str] = None,
        occupation_label: Optional[str] = None,
        page: Optional[int] = None,
        size: Optional[int] = None,
    ) -> StandardSearchResult:
        """People"""
        path = "/v1/people/all"

        # --- build query dict on the fly ---
        params: Dict[str, Any] = {}
        if name is not None:
            params["name"] = name
        if wikidata_id is not None:
            params["wikidataId"] = wikidata_id
        if occupation_id is not None:
            params["occupationId"] = occupation_id
        if occupation_label is not None:
            params["occupationLabel"] = occupation_label
        if page is not None:
            params["page"] = page
        if size is not None:
            params["size"] = size

        resp = self.api_client.request("GET", path, params=params)
        resp.raise_for_status()

        return StandardSearchResult.model_validate(resp.text)

    # ---------------- search_people_async ------------------- #
    async def search_people_async(
        self,
        name: Optional[str] = None,
        wikidata_id: Optional[str] = None,
        occupation_id: Optional[str] = None,
        occupation_label: Optional[str] = None,
        page: Optional[int] = None,
        size: Optional[int] = None,
    ) -> StandardSearchResult:
        """People (async)"""
        path = "/v1/people/all"

        params: Dict[str, Any] = {}
        if name is not None:
            params["name"] = name
        if wikidata_id is not None:
            params["wikidataId"] = wikidata_id
        if occupation_id is not None:
            params["occupationId"] = occupation_id
        if occupation_label is not None:
            params["occupationLabel"] = occupation_label
        if page is not None:
            params["page"] = page
        if size is not None:
            params["size"] = size

        resp = await self.api_client.request_async("GET", path, params=params)
        resp.raise_for_status()

        return StandardSearchResult.model_validate(resp.text)

    # ----------------- search_sources (sync) ----------------- #
    def search_sources(
        self,
        domain: Optional[str] = None,
        name: Optional[str] = None,
        source_group: Optional[str] = None,
        sort_by: Optional[str] = None,
        page: Optional[int] = None,
        size: Optional[int] = None,
        min_monthly_visits: Optional[str] = None,
        max_monthly_visits: Optional[str] = None,
        min_monthly_posts: Optional[str] = None,
        max_monthly_posts: Optional[str] = None,
        country: Optional[str] = None,
        source_country: Optional[str] = None,
        source_state: Optional[str] = None,
        source_county: Optional[str] = None,
        source_city: Optional[str] = None,
        source_lat: Optional[float] = None,
        source_lon: Optional[float] = None,
        source_max_distance: Optional[float] = None,
        category: Optional[str] = None,
        topic: Optional[str] = None,
        label: Optional[str] = None,
        paywall: Optional[str] = None,
        show_subdomains: Optional[str] = None,
        show_num_results: Optional[str] = None,
    ) -> StandardSearchResult:
        """Sources"""
        path = "/v1/sources/all"

        # --- build query dict on the fly ---
        params: Dict[str, Any] = {}
        if domain is not None:
            params["domain"] = domain
        if name is not None:
            params["name"] = name
        if source_group is not None:
            params["sourceGroup"] = source_group
        if sort_by is not None:
            params["sortBy"] = sort_by
        if page is not None:
            params["page"] = page
        if size is not None:
            params["size"] = size
        if min_monthly_visits is not None:
            params["minMonthlyVisits"] = min_monthly_visits
        if max_monthly_visits is not None:
            params["maxMonthlyVisits"] = max_monthly_visits
        if min_monthly_posts is not None:
            params["minMonthlyPosts"] = min_monthly_posts
        if max_monthly_posts is not None:
            params["maxMonthlyPosts"] = max_monthly_posts
        if country is not None:
            params["country"] = country
        if source_country is not None:
            params["sourceCountry"] = source_country
        if source_state is not None:
            params["sourceState"] = source_state
        if source_county is not None:
            params["sourceCounty"] = source_county
        if source_city is not None:
            params["sourceCity"] = source_city
        if source_lat is not None:
            params["sourceLat"] = source_lat
        if source_lon is not None:
            params["sourceLon"] = source_lon
        if source_max_distance is not None:
            params["sourceMaxDistance"] = source_max_distance
        if category is not None:
            params["category"] = category
        if topic is not None:
            params["topic"] = topic
        if label is not None:
            params["label"] = label
        if paywall is not None:
            params["paywall"] = paywall
        if show_subdomains is not None:
            params["showSubdomains"] = show_subdomains
        if show_num_results is not None:
            params["showNumResults"] = show_num_results

        resp = self.api_client.request("GET", path, params=params)
        resp.raise_for_status()

        return StandardSearchResult.model_validate(resp.text)

    # ---------------- search_sources_async ------------------- #
    async def search_sources_async(
        self,
        domain: Optional[str] = None,
        name: Optional[str] = None,
        source_group: Optional[str] = None,
        sort_by: Optional[str] = None,
        page: Optional[int] = None,
        size: Optional[int] = None,
        min_monthly_visits: Optional[str] = None,
        max_monthly_visits: Optional[str] = None,
        min_monthly_posts: Optional[str] = None,
        max_monthly_posts: Optional[str] = None,
        country: Optional[str] = None,
        source_country: Optional[str] = None,
        source_state: Optional[str] = None,
        source_county: Optional[str] = None,
        source_city: Optional[str] = None,
        source_lat: Optional[float] = None,
        source_lon: Optional[float] = None,
        source_max_distance: Optional[float] = None,
        category: Optional[str] = None,
        topic: Optional[str] = None,
        label: Optional[str] = None,
        paywall: Optional[str] = None,
        show_subdomains: Optional[str] = None,
        show_num_results: Optional[str] = None,
    ) -> StandardSearchResult:
        """Sources (async)"""
        path = "/v1/sources/all"

        params: Dict[str, Any] = {}
        if domain is not None:
            params["domain"] = domain
        if name is not None:
            params["name"] = name
        if source_group is not None:
            params["sourceGroup"] = source_group
        if sort_by is not None:
            params["sortBy"] = sort_by
        if page is not None:
            params["page"] = page
        if size is not None:
            params["size"] = size
        if min_monthly_visits is not None:
            params["minMonthlyVisits"] = min_monthly_visits
        if max_monthly_visits is not None:
            params["maxMonthlyVisits"] = max_monthly_visits
        if min_monthly_posts is not None:
            params["minMonthlyPosts"] = min_monthly_posts
        if max_monthly_posts is not None:
            params["maxMonthlyPosts"] = max_monthly_posts
        if country is not None:
            params["country"] = country
        if source_country is not None:
            params["sourceCountry"] = source_country
        if source_state is not None:
            params["sourceState"] = source_state
        if source_county is not None:
            params["sourceCounty"] = source_county
        if source_city is not None:
            params["sourceCity"] = source_city
        if source_lat is not None:
            params["sourceLat"] = source_lat
        if source_lon is not None:
            params["sourceLon"] = source_lon
        if source_max_distance is not None:
            params["sourceMaxDistance"] = source_max_distance
        if category is not None:
            params["category"] = category
        if topic is not None:
            params["topic"] = topic
        if label is not None:
            params["label"] = label
        if paywall is not None:
            params["paywall"] = paywall
        if show_subdomains is not None:
            params["showSubdomains"] = show_subdomains
        if show_num_results is not None:
            params["showNumResults"] = show_num_results

        resp = await self.api_client.request_async("GET", path, params=params)
        resp.raise_for_status()

        return StandardSearchResult.model_validate(resp.text)

    # ----------------- search_topics (sync) ----------------- #
    def search_topics(
        self,
        name: Optional[str] = None,
        category: Optional[str] = None,
        subcategory: Optional[str] = None,
        page: Optional[int] = None,
        size: Optional[int] = None,
    ) -> TableSearchResult:
        """Topics"""
        path = "/v1/topics/all"

        # --- build query dict on the fly ---
        params: Dict[str, Any] = {}
        if name is not None:
            params["name"] = name
        if category is not None:
            params["category"] = category
        if subcategory is not None:
            params["subcategory"] = subcategory
        if page is not None:
            params["page"] = page
        if size is not None:
            params["size"] = size

        resp = self.api_client.request("GET", path, params=params)
        resp.raise_for_status()

        return TableSearchResult.model_validate(resp.text)

    # ---------------- search_topics_async ------------------- #
    async def search_topics_async(
        self,
        name: Optional[str] = None,
        category: Optional[str] = None,
        subcategory: Optional[str] = None,
        page: Optional[int] = None,
        size: Optional[int] = None,
    ) -> TableSearchResult:
        """Topics (async)"""
        path = "/v1/topics/all"

        params: Dict[str, Any] = {}
        if name is not None:
            params["name"] = name
        if category is not None:
            params["category"] = category
        if subcategory is not None:
            params["subcategory"] = subcategory
        if page is not None:
            params["page"] = page
        if size is not None:
            params["size"] = size

        resp = await self.api_client.request_async("GET", path, params=params)
        resp.raise_for_status()

        return TableSearchResult.model_validate(resp.text)
